@@ -65,7 +65,7 @@ static int semanage_direct_list(semanage_handle_t * sh,
 				int *num_modules);
 
 static struct semanage_policy_table direct_funcs = {
-	.get_serial = semanage_get_commit_number,
+	.get_serial = semanage_direct_get_serial,
 	.destroy = semanage_direct_destroy,
 	.disconnect = semanage_direct_disconnect,
 	.begin_trans = semanage_direct_begintrans,
@@ -467,9 +467,11 @@ static int semanage_direct_commit(semanage_handle_t * sh)
 
 	/* Before we do anything else, flush the join to its component parts.
 	 * This *does not* flush to disk automatically */
-	if (users->dtable->is_modified(users->dbase) &&
-	    users->dtable->flush(sh, users->dbase) < 0)
-		goto cleanup;
+	if (users->dtable->is_modified(users->dbase)) {
+		retval = users->dtable->flush(sh, users->dbase);
+		if (retval < 0)
+			goto cleanup;
+	}
 
 	/* Decide if anything was modified */
 	fcontexts_modified = fcontexts->dtable->is_modified(fcontexts->dbase);
@@ -497,85 +499,117 @@ static int semanage_direct_commit(semanage_handle_t * sh)
 		/* =================== Module expansion =============== */
 
 		/* link all modules in the sandbox to the base module */
-		if (semanage_get_modules_names
-		    (sh, &mod_filenames, &num_modfiles) != 0
-		    || semanage_verify_modules(sh, mod_filenames,
-					       num_modfiles) == -1
-		    || semanage_link_sandbox(sh, &base) < 0) {
+		retval = semanage_get_modules_names(sh, &mod_filenames, &num_modfiles);
+		if (retval < 0)
+			goto cleanup;
+		retval = semanage_verify_modules(sh, mod_filenames, num_modfiles);
+		if (retval < 0)
+			goto cleanup;
+		retval = semanage_link_sandbox(sh, &base);
+		if (retval < 0)
+			goto cleanup;
+
+		/* write the linked base if we want to save or we have a
+		 * verification program that wants it. */
+		linked_filename = semanage_path(SEMANAGE_TMP, SEMANAGE_LINKED);
+		if (linked_filename == NULL) {
+			retval = -1;
 			goto cleanup;
 		}
-
-		/* write the linked base */
-		if ((linked_filename =
-		     semanage_path(SEMANAGE_TMP, SEMANAGE_LINKED)) == NULL
-		    || semanage_write_module(sh, linked_filename, base) == -1
-		    || semanage_verify_linked(sh) != 0) {
-			goto cleanup;
+		if (sh->conf->save_linked || sh->conf->linked_prog) {
+			retval = semanage_write_module(sh, linked_filename, base);
+			if (retval < 0)
+				goto cleanup;
+			retval = semanage_verify_linked(sh);
+			if (retval < 0)
+				goto cleanup;
+			/* remove the linked policy if we only wrote it for the
+			 * verification program. */
+			if (!sh->conf->save_linked) {
+				retval = unlink(linked_filename);
+				if (retval < 0) {
+					ERR(sh, "could not remove linked base %s",
+					    linked_filename);
+					goto cleanup;
+				}
+			}
+		} else {
+			/* Try to delete the linked copy - this is needed if
+			 * the save_link option has changed to prevent the
+			 * old linked copy from being copied forever. No error
+			 * checking is done because this is likely to fail because
+			 * the file does not exist - which is not an error. */
+			unlink(linked_filename);
 		}
 
 		/* ==================== File-backed ================== */
 
 		/* File Contexts */
 		/* Sort the file contexts. */
-		if (semanage_fc_sort
-		    (sh, sepol_module_package_get_file_contexts(base),
-		     sepol_module_package_get_file_contexts_len(base),
-		     &sorted_fc_buffer, &sorted_fc_buffer_len) == -1) {
+		retval = semanage_fc_sort(sh, sepol_module_package_get_file_contexts(base),
+					  sepol_module_package_get_file_contexts_len(base),
+					  &sorted_fc_buffer, &sorted_fc_buffer_len);
+		if (retval < 0)
 			goto cleanup;
-		}
 
 		/* Write the contexts (including template contexts) to a single file.  
 		 * The buffer returned by the sort function has a trailing \0 character,
 		 * which we do NOT want to write out to disk, so we pass sorted_fc_buffer_len-1. */
-		if ((ofilename =
-		     semanage_path(SEMANAGE_TMP, SEMANAGE_FC_TMPL)) == NULL
-		    || write_file(sh, ofilename, sorted_fc_buffer,
-				  sorted_fc_buffer_len - 1) == -1) {
+		ofilename = semanage_path(SEMANAGE_TMP, SEMANAGE_FC_TMPL);
+		if (ofilename == NULL) {
+			retval = -1;
 			goto cleanup;
 		}
+		retval = write_file(sh, ofilename, sorted_fc_buffer,
+				    sorted_fc_buffer_len - 1);
+		if (retval < 0)
+			goto cleanup;
 
 		/* Split complete and template file contexts into their separate files. */
-		if (semanage_split_fc(sh))
+		retval = semanage_split_fc(sh);
+		if (retval < 0)
 			goto cleanup;
 
 		pfcontexts->dtable->drop_cache(pfcontexts->dbase);
 
 		/* Seusers */
 		if (sepol_module_package_get_seusers_len(base)) {
-			if ((ofilename =
-			     semanage_path(SEMANAGE_TMP,
-					   SEMANAGE_SEUSERS)) == NULL
-			    || write_file(sh, ofilename,
-					  sepol_module_package_get_seusers
-					  (base),
-					  sepol_module_package_get_seusers_len
-					  (base)) == -1) {
+			ofilename = semanage_path(SEMANAGE_TMP, SEMANAGE_SEUSERS);
+			if (ofilename == NULL) {
+				retval = -1;
 				goto cleanup;
 			}
+			retval = write_file(sh, ofilename,
+					    sepol_module_package_get_seusers(base),
+					    sepol_module_package_get_seusers_len(base));
+			if (retval < 0)
+				goto cleanup;
+
 			pseusers->dtable->drop_cache(pseusers->dbase);
 
 		} else {
-			if (pseusers->dtable->clear(sh, pseusers->dbase) < 0)
+			retval = pseusers->dtable->clear(sh, pseusers->dbase);
+			if (retval < 0)
 				goto cleanup;
 		}
 
 		/* Users_extra */
 		if (sepol_module_package_get_user_extra_len(base)) {
-			if ((ofilename =
-			     semanage_path(SEMANAGE_TMP,
-					   SEMANAGE_USERS_EXTRA)) == NULL
-			    || write_file(sh, ofilename,
-					  sepol_module_package_get_user_extra
-					  (base),
-					  sepol_module_package_get_user_extra_len
-					  (base)) == -1) {
+			ofilename = semanage_path(SEMANAGE_TMP, SEMANAGE_USERS_EXTRA);
+			if (ofilename == NULL) {
+				retval = -1;
 				goto cleanup;
 			}
+			retval = write_file(sh, ofilename,
+					    sepol_module_package_get_user_extra(base),
+					    sepol_module_package_get_user_extra_len(base));
+			if (retval < 0)
+				goto cleanup;
 			pusers_extra->dtable->drop_cache(pusers_extra->dbase);
 
 		} else {
-			if (pusers_extra->dtable->
-			    clear(sh, pusers_extra->dbase) < 0)
+			retval = pusers_extra->dtable->clear(sh, pusers_extra->dbase);
+			if (retval < 0)
 				goto cleanup;
 		}
 
@@ -603,7 +637,8 @@ static int semanage_direct_commit(semanage_handle_t * sh)
 
 		/* Create new policy object, then attach to policy databases
 		 * that work with a policydb */
-		if (semanage_expand_sandbox(sh, base, &out) < 0)
+		retval = semanage_expand_sandbox(sh, base, &out);
+		if (retval < 0)
 			goto cleanup;
 
 		dbase_policydb_attach((dbase_policydb_t *) pusers_base->dbase,
@@ -615,13 +650,16 @@ static int semanage_direct_commit(semanage_handle_t * sh)
 
 		/* ============= Apply changes, and verify  =============== */
 
-		if (semanage_base_merge_components(sh) < 0)
+		retval = semanage_base_merge_components(sh);
+		if (retval < 0)
 			goto cleanup;
 
-		if (semanage_write_policydb(sh, out) < 0)
+		retval = semanage_write_policydb(sh, out);
+		if (retval < 0)
 			goto cleanup;
 
-		if (semanage_verify_kernel(sh) != 0)
+		retval = semanage_verify_kernel(sh);
+		if (retval < 0)
 			goto cleanup;
 	}
 
@@ -635,29 +673,35 @@ static int semanage_direct_commit(semanage_handle_t * sh)
 	 * merged into the main file_contexts. We won't check the 
 	 * large file_contexts - checked at compile time */
 	if (sh->do_rebuild || modified || fcontexts_modified) {
-		if (semanage_fcontext_validate_local(sh, out) < 0)
+		retval = semanage_fcontext_validate_local(sh, out);
+		if (retval < 0)
 			goto cleanup;
 	}
 
 	/* Validate local seusers against policy */
 	if (sh->do_rebuild || modified || seusers_modified) {
-		if (semanage_seuser_validate_local(sh, out) < 0)
+		retval = semanage_seuser_validate_local(sh, out);
+		if (retval < 0)
 			goto cleanup;
 	}
 
 	/* Validate local ports for overlap */
 	if (sh->do_rebuild || ports_modified) {
-		if (semanage_port_validate_local(sh) < 0)
+		retval = semanage_port_validate_local(sh);
+		if (retval < 0)
 			goto cleanup;
 	}
 
 	/* ================== Write non-policydb components ========= */
 
 	/* Commit changes to components */
-	if (semanage_commit_components(sh) < 0)
+	retval = semanage_commit_components(sh);
+	if (retval < 0)
 		goto cleanup;
 
-	retval = semanage_install_sandbox(sh);
+	if (sh->do_rebuild || modified) {
+		retval = semanage_install_sandbox(sh);
+	}
 
       cleanup:
 	for (i = 0; mod_filenames != NULL && i < num_modfiles; i++) {
@@ -869,7 +913,7 @@ static int semanage_direct_list(semanage_handle_t * sh,
 		goto cleanup;
 	}
 	if (num_mod_files == 0) {
-		retval = semanage_get_commit_number(sh);
+		retval = semanage_direct_get_serial(sh);
 		goto cleanup;
 	}
 
@@ -912,7 +956,7 @@ static int semanage_direct_list(semanage_handle_t * sh,
 			free(version);
 		}
 	}
-	retval = semanage_get_commit_number(sh);
+	retval = semanage_direct_get_serial(sh);
 
       cleanup:
 	sepol_policy_file_free(pf);
