@@ -37,7 +37,8 @@
 
 #define SEMANAGE_COMMIT_READ_WAIT 5
 
-semanage_handle_t *semanage_handle_create(void) {
+semanage_handle_t *semanage_handle_create(void)
+{
 	semanage_handle_t *sh = NULL;
 	const char *conf_name = NULL;
 
@@ -48,7 +49,7 @@ semanage_handle_t *semanage_handle_create(void) {
 	if ((conf_name = semanage_conf_path()) == NULL)
 		goto err;
 
-	if ((sh->conf = semanage_conf_parse(conf_name)) == NULL) 
+	if ((sh->conf = semanage_conf_parse(conf_name)) == NULL)
 		goto err;
 
 	/* Link to sepol handle */
@@ -68,20 +69,21 @@ semanage_handle_t *semanage_handle_create(void) {
 	sh->create_store = 0;
 
 	/* Set timeout: some default value for now, later use config */
-	sh->timeout = SEMANAGE_COMMIT_READ_WAIT; 
+	sh->timeout = SEMANAGE_COMMIT_READ_WAIT;
 
 	/* Set callback */
 	sh->msg_callback = semanage_msg_default_handler;
 	sh->msg_callback_arg = NULL;
 
-        return sh;
+	return sh;
 
- err:
+      err:
 	semanage_handle_destroy(sh);
 	return NULL;
 }
 
-void semanage_set_rebuild(semanage_handle_t *sh, int do_rebuild) {
+void semanage_set_rebuild(semanage_handle_t * sh, int do_rebuild)
+{
 
 	assert(sh != NULL);
 
@@ -89,30 +91,34 @@ void semanage_set_rebuild(semanage_handle_t *sh, int do_rebuild) {
 	return;
 }
 
-void semanage_set_reload(semanage_handle_t *sh, int do_reload) {
-	
+void semanage_set_reload(semanage_handle_t * sh, int do_reload)
+{
+
 	assert(sh != NULL);
 
 	sh->do_reload = do_reload;
 	return;
 }
 
-void semanage_set_create_store(semanage_handle_t *sh, int create_store) {
-	
+void semanage_set_create_store(semanage_handle_t * sh, int create_store)
+{
+
 	assert(sh != NULL);
 
 	sh->create_store = create_store;
 	return;
 }
 
-int semanage_is_connected(semanage_handle_t *sh) {
+int semanage_is_connected(semanage_handle_t * sh)
+{
 	assert(sh != NULL);
 	return sh->is_connected;
 }
 
-void semanage_select_store(semanage_handle_t *sh, char *storename,
-			  enum semanage_connect_type storetype) {
-	
+void semanage_select_store(semanage_handle_t * sh, char *storename,
+			   enum semanage_connect_type storetype)
+{
+
 	assert(sh != NULL);
 
 	/* This just sets the storename to what the user requests, no 
@@ -123,7 +129,7 @@ void semanage_select_store(semanage_handle_t *sh, char *storename,
 	return;
 }
 
-int semanage_is_managed(semanage_handle_t *sh)
+int semanage_is_managed(semanage_handle_t * sh)
 {
 	assert(sh != NULL);
 	if (sh->is_connected) {
@@ -134,45 +140,52 @@ int semanage_is_managed(semanage_handle_t *sh)
 	case SEMANAGE_CON_DIRECT:
 		return semanage_direct_is_managed(sh);
 	default:
-		ERR(sh, "The connection type specified within your semanage.conf file has not been implemented yet.");
+		ERR(sh,
+		    "The connection type specified within your semanage.conf file has not been implemented yet.");
 		/* fall through */
 	}
 	return -1;
 }
 
-int semanage_connect(semanage_handle_t *sh) {
+int semanage_connect(semanage_handle_t * sh)
+{
 	assert(sh != NULL);
 	switch (sh->conf->store_type) {
-	case SEMANAGE_CON_DIRECT: {
-		if (semanage_direct_connect(sh) < 0) {
+	case SEMANAGE_CON_DIRECT:{
+			if (semanage_direct_connect(sh) < 0) {
+				return -1;
+			}
+			break;
+		}
+	default:{
+			ERR(sh,
+			    "The connection type specified within your semanage.conf file has not been implemented yet.");
 			return -1;
 		}
-		break;
-	}
-	default: {
-		ERR(sh, "The connection type specified within your semanage.conf file has not been implemented yet.");
-		return -1;
-	}
 	}
 	sh->is_connected = 1;
 	return 0;
 }
 
-int semanage_access_check(semanage_handle_t *sh) {
+int semanage_access_check(semanage_handle_t * sh)
+{
 	assert(sh != NULL);
 	switch (sh->conf->store_type) {
-	case SEMANAGE_CON_DIRECT: 
+	case SEMANAGE_CON_DIRECT:
 		return semanage_direct_access_check(sh);
 	default:
 		return -1;
 	}
 
-	return -1; /* unreachable */
+	return -1;		/* unreachable */
 }
+
 hidden_def(semanage_access_check)
 
-int semanage_disconnect(semanage_handle_t *sh) {
-	assert(sh != NULL && sh->funcs != NULL && sh->funcs->disconnect != NULL);
+int semanage_disconnect(semanage_handle_t * sh)
+{
+	assert(sh != NULL && sh->funcs != NULL
+	       && sh->funcs->disconnect != NULL);
 	if (!sh->is_connected) {
 		return 0;
 	}
@@ -185,7 +198,8 @@ int semanage_disconnect(semanage_handle_t *sh) {
 	return 0;
 }
 
-void semanage_handle_destroy(semanage_handle_t *sh) {
+void semanage_handle_destroy(semanage_handle_t * sh)
+{
 	if (sh == NULL)
 		return;
 
@@ -195,12 +209,14 @@ void semanage_handle_destroy(semanage_handle_t *sh) {
 	sepol_handle_destroy(sh->sepolh);
 	free(sh);
 }
+
 hidden_def(semanage_handle_destroy)
 
 /********************* public transaction functions *********************/
-
-int semanage_begin_transaction(semanage_handle_t *sh) {
-	assert(sh != NULL && sh->funcs != NULL && sh->funcs->begin_trans != NULL);
+int semanage_begin_transaction(semanage_handle_t * sh)
+{
+	assert(sh != NULL && sh->funcs != NULL
+	       && sh->funcs->begin_trans != NULL);
 	if (!sh->is_connected) {
 		ERR(sh, "Not connected.");
 		return -1;
@@ -215,13 +231,16 @@ int semanage_begin_transaction(semanage_handle_t *sh) {
 	sh->is_in_transaction = 1;
 	return 0;
 }
+
 hidden_def(semanage_begin_transaction)
 
-int semanage_commit(semanage_handle_t *sh) {
+int semanage_commit(semanage_handle_t * sh)
+{
 	int retval;
 	assert(sh != NULL && sh->funcs != NULL && sh->funcs->commit != NULL);
 	if (!sh->is_in_transaction) {
-		ERR(sh, "Will not commit because caller does not have a tranaction lock yet.");
+		ERR(sh,
+		    "Will not commit because caller does not have a tranaction lock yet.");
 		return -1;
 	}
 	retval = sh->funcs->commit(sh);
