@@ -35,6 +35,8 @@ typedef struct semanage_conf {
 	int server_port;
 	int policyvers;		/* version for server generated policies */
 	int expand_check;
+	int save_previous;
+	int save_linked;
 	mode_t file_mode;
 	struct external_prog *load_policy;
 	struct external_prog *setfiles;
