@@ -968,14 +968,14 @@ int semanage_split_fc(semanage_handle_t * sh)
 		if (!strncmp(buf, "HOME_DIR", 8) ||
 		    !strncmp(buf, "HOME_ROOT", 9) || strstr(buf, "ROLE")) {
 			/* This contains one of the template variables, write it to homedir.template */
-			if (write(hd, buf, strnlen(buf, PATH_MAX)) == 0) {
+			if (write(hd, buf, strlen(buf)) == 0) {
 				ERR(sh, "Write to %s failed.",
 				    semanage_path(SEMANAGE_TMP,
 						  SEMANAGE_HOMEDIR_TMPL));
 				goto cleanup;
 			}
 		} else {
-			if (write(fc, buf, strnlen(buf, PATH_MAX)) == 0) {
+			if (write(fc, buf, strlen(buf)) == 0) {
 				ERR(sh, "Write to %s failed.",
 				    semanage_path(SEMANAGE_TMP, SEMANAGE_FC));
 				goto cleanup;
@@ -1151,7 +1151,7 @@ static int semanage_commit_sandbox(semanage_handle_t * sh)
 	struct stat buf;
 
 	/* update the commit number */
-	if ((commit_number = semanage_get_commit_number(sh)) < 0) {
+	if ((commit_number = semanage_direct_get_serial(sh)) < 0) {
 		return -1;
 	}
 	commit_number++;
@@ -1224,6 +1224,14 @@ static int semanage_commit_sandbox(semanage_handle_t * sh)
 		goto cleanup;
 	}
 
+	if (!sh->conf->save_previous) {
+		retval = semanage_remove_directory(backup);
+		if (retval < 0) {
+			ERR(sh, "Could not delete previous directory %s.", backup);
+			goto cleanup;
+		}
+	}
+
       cleanup:
 	semanage_release_active_lock(sh);
 	return retval;
@@ -1404,7 +1412,7 @@ void semanage_release_active_lock(semanage_handle_t * sh)
 /* Read the current commit number from the commit number file which
  * the handle is pointing, resetting the file pointer afterwards.
  * Return it (a non-negative number), or -1 on error. */
-int semanage_get_commit_number(semanage_handle_t * sh)
+int semanage_direct_get_serial(semanage_handle_t * sh)
 {
 	char buf[32];
 	int fd, commit_number;
